@@ -18,6 +18,10 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <tqstring.h>
 #include <tqstringlist.h>
 #include <tqvaluelist.h>
@@ -220,7 +224,7 @@ void Archive::saveBasketToArchive(Basket *basket, bool recursive, KTar *tar, TQS
 	}
 
 	progress->advance(1); // Basket exportation finished
-	std::cout << basket->basketName() << " finished" << std::endl;
+	std::cout << basket->basketName().local8Bit() << " finished" << std::endl;
 
 	// Recursively save child baskets:
 	BasketListViewItem *item = Global::bnpView->listViewItemForBasket(basket);
